#============================================================================
# install_dir.mk

INSTALL_DIR_MK =

# this snippet defines a sequence of shell commands which will
#
#  * recursively copy the *CONTENTS* of a directory to a destination.
#  * uninstall an installed directory

# during the install it first checks for the directory in the current
# directory; if it is not found there, it assumes it is in $srcdir.

# during the uninstall it removes only those files which are found in
# the provided original source directory.  that directory may be in
# the current directory, else it is assumed to be in $srcdir

# To use this, set these shell variables
#
#  src_dir - the directory holding the original files
#  dst_dir - the directory where the files are to be installed
#
#
# and then interpolate $(install_dir) and $(uninstall_dir).  For example
#
#  src_dir=$(_HTML); dst_dir=$(htmldir); $(install_dir)

# TAR and FIND must be defined
TAR  +=
FIND +=

# use tar to ensure we get all the dot files and permissions
install_dir =	\
	$(MKDIR_P) "$(DESTDIR)$${dst_dir}"; \
	if test -d "$${src_dir}"; then d=; else d="$(srcdir)/"; fi; \
	$(TAR) cf - -C "$$d$${src_dir}" . | { cd "$(DESTDIR)$${dst_dir}" ; tar xvf -; }

# painstakingly delete each file and directory present in srcdir one
# by one.
# 1. use find to create top-down list of files and directories
# 2. chmod +w on the directories and pass those along in the pipe
# 3. delete the files
# 4. sort the directories by reverse length; gives us bottom-up
# 5. remove directories (now in bottom-up order)
# 6. delete ${dst_dir}
uninstall_dir = \
	if test -d "$${src_dir}"; then d=; else d="$(srcdir)/"; fi; \
	  { cd "$$d$${src_dir}" ; $(FIND) . ; } \
	 |{ cd "$(DESTDIR)$${dst_dir}"; \
	    chmod +w . ;\
	    while read entry; do \
	      if  test -d "$$entry" -a "$$entry" != '.' -a "$$entry" != './'; then \
	        chmod +w "$$entry" ;\
		echo "$${\#entry} $$entry" ;\
	      elif test -f "$$entry"; then rm -f "$$entry" ; fi;\
	     done \
	   |sort -nr \
	   |while read len entry; do rmdir $$entry ; done ;\
	  }  && rmdir "$(DESTDIR)$${dst_dir}"

